@@ -1,28 +1,25 @@
-import warnings
-warnings.filterwarnings("ignore")
-
-import pandas as pd
-from pathlib import Path
-import numpy as np
-import json
-import matplotlib.pyplot as plt
-from dlcu import PlottingResults, time_in_each_roi
-from collections import namedtuple
-import matplotlib.patches as patches
-import glob
 import os
+import glob
+from toxopy import fwarnings
+import matplotlib.patches as patches
+from collections import namedtuple
+from dlcu import time_in_each_roi
+import matplotlib.pyplot as plt
+import json
+import numpy as np
+from pathlib import Path
+import pandas as pd
+
 # %matplotlib inline
 
 
-def analyze_rois(file, room_layout, output_dir, trial_type, span=''):
+def analyze_rois(file, room_layout, output_dir, trial_type, span=10):
 
-    if output_dir.endswith('/') == False:
+    if output_dir.endswith('/') is False:
 
         raise ValueError(
             'Output directory does not end with a trailing slash "/"!')
-
-    else:
-        pass
+    pass
 
     # Load dataset
 
@@ -67,7 +64,9 @@ def analyze_rois(file, room_layout, output_dir, trial_type, span=''):
 
     for trial, trial_name in zip(trials, trials_names):
 
-        time = trial['time']
+        # time = trial['time']
+        span = str(span)
+
         velocity = trial['velocity_loess' + span]
 
         if trial_type == 'with_owner':
@@ -82,28 +81,22 @@ def analyze_rois(file, room_layout, output_dir, trial_type, span=''):
 
         # Calculate and plot rois
 
-        def rois_gen(i):
-            def getList(dict):
-                list = []
-                for key in dict.keys():
-                    list.append(key)
+        # def rois_gen(i):
+        #     def getList(dct):
+        #         lst = []
+        #         for key in dct.keys():
+        #             lst.append(key)
 
-                return list
+        #         return lst
 
             with open(room_layout) as json_file:
                 p = json.load(json_file)
 
-            catslist = getList(p)
-
-            positions = [
-                'middle', 'rightside', 'leftside', 'topside', 'bottomside'
-            ]
-
-            colors = ['orange', 'purple', 'red', 'blue', 'green']
+            # catslist = getList(p)
 
             position = namedtuple('position', ['topleft', 'bottomright'])
 
-            #two points defining each roi: topleft(X,Y) and bottomright(X,Y).
+            # two points defining each roi: topleft(X,Y) and bottomright(X,Y).
 
             return {
                 'middle':
@@ -159,9 +152,9 @@ def analyze_rois(file, room_layout, output_dir, trial_type, span=''):
 
         current_trial = []
 
-        for x in range(0, len(res)):
+        # for x in range(0, len(res)):
 
-            current_trial.append(trial_name)
+        #     current_trial.append(trial_name)
 
         res['trial'] = current_trial
 
